@@ -1022,7 +1022,7 @@ class AppWindow(GladeDelegate):
 
     def _on_ToggleFullscreen__notify_active(self, action, spec):
         window = self.get_toplevel()
-        if not window.get_realized():
+        if not (window.flags() & gtk.REALIZED):
             return
         is_active = action.get_active()
         is_fullscreen = window.window.get_state() & gtk.gdk.WINDOW_STATE_FULLSCREEN
