@@ -51,8 +51,9 @@ from stoqlib.gui.editors.accounteditor import AccountEditor
 from stoqlib.gui.editors.accounttransactioneditor import AccountTransactionEditor
 from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
-from stoqlib.gui.dialogs.sintegradialog import month_names
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
+from stoqlib.lib.dateconstants import get_month_names
 from stoqlib.lib.message import yesno
 from stoqlib.reporting.payment import AccountTransactionReport
 
@@ -133,13 +134,14 @@ class TransactionPage(object):
         self.date_filter.clear_options()
         self.date_filter.add_option(Any, 0)
         year = datetime.datetime.today().year
-        for i in range(1, 13):
+        month_names = get_month_names()
+        for i, month in enumerate(month_names):
             name = month_names[i]
             option = type(name + 'Option', (MonthOption, ),
                           {'name': gettext.gettext(name),
-                           'month': i,
+                           'month': i + 1,
                            'year': year})
-            self.date_filter.add_option(option, i)
+            self.date_filter.add_option(option, i + 1)
         self.date_filter.add_custom_options()
         self.date_filter.mode.select_item_by_position(0)
         self.search.add_filter(self.date_filter)
@@ -250,7 +252,7 @@ class TransactionPage(object):
             description = transaction.get_account_description(self.model)
             value = transaction.get_value(self.model)
             self._add_transaction(transaction, description, value)
-        self._update_totals()
+        self.update_totals()
 
     def _populate_payable_payments(self, view_class):
         for view in view_class.select():
@@ -269,7 +271,7 @@ class TransactionPage(object):
         item.value = value
         item.code = transaction.code
 
-    def _update_totals(self):
+    def update_totals(self):
         total = decimal.Decimal('0')
         for item in self.search.results:
             total += item.value
@@ -291,7 +293,7 @@ class TransactionPage(object):
             self._update_transaction(item, transaction,
                                      transaction.edited_account.description,
                                      transaction.value)
-            self._update_totals()
+            self.update_totals()
             self.search.results.update(item)
             self.app.accounts.refresh_accounts(self.app.conn)
         api.finish_transaction(trans, transaction)
@@ -316,7 +318,7 @@ class TransactionPage(object):
             if other == model:
                 value = -value
             item = self._add_transaction(transaction, other.description, value)
-            self._update_totals()
+            self.update_totals()
             self.search.results.update(item)
             self.app.accounts.refresh_accounts(self.app.conn)
         api.finish_transaction(trans, transaction)
@@ -329,7 +331,6 @@ class TransactionPage(object):
 class FinancialApp(AppWindow):
 
     app_name = _('Financial')
-    app_icon_name = 'stoq-financial-app'
     gladefile = 'financial'
     embedded = True
 
@@ -338,44 +339,45 @@ class FinancialApp(AppWindow):
         self.accounts = AccountTree()
         AppWindow.__init__(self, app)
         self._tills_account = api.sysparam(self.conn).TILLS_ACCOUNT
+        self._banks_account = api.sysparam(self.conn).BANKS_ACCOUNT
 
     #
     # AppWindow overrides
     #
 
     def create_actions(self):
+        group = get_accels('app.financial')
         actions = [
-            ('menubar', None, ''),
-
-            # Financial
-            ('Print', gtk.STOCK_PRINT, _("Print..."),
-             None, _('Print a transaction report')),
+            ('TransactionMenu', None, _('Transaction')),
+            ('AccountMenu', None, _('Account')),
             ('Import', gtk.STOCK_ADD, _('Import...'),
-             '<control>i', _('Import a GnuCash or OFX file')),
-            ('ExportCSV', None, _('Export CSV...'), '<control>F10'),
-
-            # Toolbar
-            ('toolbar', None, ''),
-            ('EditAccount', gtk.STOCK_EDIT, _('Edit account'),
-             '<control>e', _('Change the currently selected account')),
-            ('DeleteAccount', gtk.STOCK_DELETE, _('Delete account'), '',
+             group.get('import'), _('Import a GnuCash or OFX file')),
+            ('DeleteAccount', gtk.STOCK_DELETE, _('Delete...'),
+             group.get('delete_account'),
              _('Delete the selected account')),
-            ('DeleteTransaction', gtk.STOCK_DELETE, _('Delete transaction'), '',
+            ('DeleteTransaction', gtk.STOCK_DELETE, _('Delete...'),
+             group.get('delete_transaction'),
              _('Delete the selected transaction')),
-
-            # Toolbar
-            ("NewAccount", gtk.STOCK_NEW, _("Account..."), '<control>a',
+            ("NewAccount", gtk.STOCK_NEW, _("Account..."),
+             group.get('new_account'),
              _("Add a new account")),
-            ("NewTransaction", gtk.STOCK_NEW, _("Transaction..."), '<control>t',
+            ("NewTransaction", gtk.STOCK_NEW, _("Transaction..."),
+             group.get('new_transaction'),
              _("Add a new transaction")),
-            ("Edit", gtk.STOCK_EDIT, _("Edit"), ''),
-
+            ("Edit", gtk.STOCK_EDIT, _("Edit..."),
+             group.get('edit')),
             ]
         self.financial_ui = self.add_ui_actions('', actions,
                                                 filename='financial.xml')
-        self.set_help_section(_("Financial help"), 'financial-inicio')
+        self.set_help_section(_("Financial help"), 'app-financial')
+        self.Edit.set_short_label(_('Edit'))
+        self.DeleteAccount.set_short_label(_('Delete'))
+        self.DeleteTransaction.set_short_label(_('Delete'))
 
     def create_ui(self):
+        self.trans_popup = self.uimanager.get_widget('/TransactionSelection')
+        self.acc_popup = self.uimanager.get_widget('/AccountSelection')
+
         self.app.launcher.add_new_items([self.NewAccount,
                                          self.NewTransaction])
 
@@ -384,7 +386,7 @@ class FinancialApp(AppWindow):
         self._create_initial_page()
         self._refresh_accounts()
 
-    def activate(self):
+    def activate(self, params):
         for page in self._pages.values():
             page.refresh()
         self._update_actions()
@@ -395,26 +397,40 @@ class FinancialApp(AppWindow):
         self.uimanager.remove_ui(self.financial_ui)
         self.app.launcher.SearchToolItem.set_sensitive(True)
 
+    def print_activate(self):
+        self._print_transaction_report()
+
+    def export_csv_activate(self):
+        self._export_csv()
+
     #
     # Private
     #
 
     def _update_actions(self):
+        is_accounts_tab = self._is_accounts_tab()
+        self.AccountMenu.set_visible(is_accounts_tab)
+        self.TransactionMenu.set_visible(not is_accounts_tab)
+        self.DeleteAccount.set_visible(is_accounts_tab)
+        self.DeleteTransaction.set_visible(not is_accounts_tab)
+        self.app.launcher.ExportCSV.set_sensitive(not is_accounts_tab)
+        self.app.launcher.Print.set_sensitive(not is_accounts_tab)
+
         self.NewAccount.set_sensitive(self._can_add_account())
-        self.EditAccount.set_sensitive(self._can_edit_account())
         self.DeleteAccount.set_sensitive(self._can_delete_account())
         self.NewTransaction.set_sensitive(self._can_add_transaction())
         self.DeleteTransaction.set_sensitive(self._can_delete_transaction())
-        self.ExportCSV.set_sensitive(self._can_export_csv())
         self.Edit.set_sensitive(self._can_edit_account() or
                                 self._can_edit_transaction())
-        self.Print.set_sensitive(self._is_transaction_tab())
 
     def _update_tooltips(self):
         if self._is_accounts_tab():
             self.Edit.set_tooltip(_("Edit the selected account"))
+            self.app.launcher.Print.set_tooltip("")
         else:
             self.Edit.set_tooltip(_("Edit the selected transaction"))
+            self.app.launcher.Print.set_tooltip(
+                _("Print a report of these transactions"))
 
     def _create_initial_page(self):
         pixbuf = self.accounts.render_icon('stoq-money', gtk.ICON_SIZE_MENU)
@@ -532,6 +548,8 @@ class FinancialApp(AppWindow):
                                    self, self.get_toplevel())
             page.search.results.connect('selection-changed',
                                         self._on_transaction__selection_changed)
+            page.search.results.connect('right-click',
+                                        self._on_transaction__right_click)
             hbox = self._create_tab_label(account_view.description, pixbuf, page)
             page_id = self.notebook.append_page(page.search, hbox)
             page.show()
@@ -616,6 +634,8 @@ class FinancialApp(AppWindow):
         if account_view.kind != 'account':
             return False
 
+        if account_view.id == self._banks_account.id:
+            return
         return True
 
     def _can_delete_account(self):
@@ -659,9 +679,6 @@ class FinancialApp(AppWindow):
 
         return True
 
-    def _can_export_csv(self):
-        return not self._is_accounts_tab()
-
     def _add_transaction(self):
         page = self._get_current_page_widget()
         page.add_transaction_dialog()
@@ -703,9 +720,10 @@ class FinancialApp(AppWindow):
             account_transaction = trans.get(item.transaction)
         account_transaction.delete(account_transaction.id, connection=trans)
         trans.commit(close=True)
+        account_transactions.update_totals()
 
     def _print_transaction_report(self):
-        assert self._is_transaction_tab()
+        assert not self._is_accounts_tab()
 
         page = self._get_current_page_widget()
         print_report(AccountTransactionReport, page.results, list(page.results),
@@ -735,6 +753,12 @@ class FinancialApp(AppWindow):
     def on_accounts__selection_changed(self, ktree, account_view):
         self._update_actions()
 
+    def _on_transaction__right_click(self, results, result, event):
+        self.trans_popup.popup(None, None, None, event.button, event.time)
+
+    def on_accounts__right_click(self, results, result, event):
+        self.acc_popup.popup(None, None, None, event.button, event.time)
+
     def on_Edit__activate(self, button):
         account_view = self.accounts.get_selected()
         self._edit_existing_account(account_view)
@@ -765,14 +789,9 @@ class FinancialApp(AppWindow):
         transactions = self._get_current_page_widget()
         transaction = transactions.results.get_selected()
         self._delete_transaction(transaction)
+        self._refresh_accounts()
 
     # Financial
 
-    def on_Print__activate(self, action):
-        self._print_transaction_report()
-
     def on_Import__activate(self, action):
         self._import()
-
-    def on_ExportCSV__activate(self, action):
-        self._export_csv()
