@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -35,30 +35,31 @@ import gtk
 from kiwi.datatypes import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
-from kiwi.ui.search import ComboSearchFilter
+from kiwi.ui.gadgets import render_pixbuf
 from kiwi.ui.objectlist import SearchColumn, Column
+from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from stoqlib.api import api
 from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import InPaymentView
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import TillError
-from stoqlib.reporting.payment import ReceivablePaymentReport
-from stoqlib.reporting.receival_receipt import ReceivalReceipt
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.gtkadds import render_pixbuf
 from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
                                                      PaymentStatusChangeDialog)
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.dialogs.paymentflowhistorydialog import PaymentFlowHistoryDialog
 from stoqlib.gui.editors.paymenteditor import InPaymentEditor
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.paymentsearch import InPaymentBillCheckSearch
 from stoqlib.gui.search.paymentsearch import CardPaymentSearch
 from stoqlib.gui.slaves.installmentslave import SaleInstallmentConfirmationSlave
 from stoqlib.gui.wizards.renegotiationwizard import PaymentRenegotiationWizard
-from stoqlib.lib.boleto import BillReport, can_generate_bill
 from stoqlib.lib.message import warning
+from stoqlib.reporting.boleto import BillReport
+from stoqlib.reporting.payment import ReceivablePaymentReport
+from stoqlib.reporting.payments_receipt import InPaymentReceipt
 
 from stoq.gui.application import SearchableAppWindow
 
@@ -70,10 +71,10 @@ class ReceivableApp(SearchableAppWindow):
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
     app_name = _('Accounts receivable')
-    app_icon_name = 'stoq-bills'
     gladefile = 'receivable'
     search_table = InPaymentView
     search_label = _('matching:')
+    report_table = ReceivablePaymentReport
     embedded = True
 
     #
@@ -81,70 +82,83 @@ class ReceivableApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.receivable')
         actions = [
-            ('menubar', None, ''),
-
-            # Payable
+            # File
             ('AddReceiving', gtk.STOCK_ADD, _('Account receivable...'),
-             '<Control>p'),
-            ('CancelPayment', gtk.STOCK_REMOVE, _('Cancel payment...')),
-            ('SetNotPaid', gtk.STOCK_UNDO, _('Set as not paid...')),
-            ('ChangeDueDate', gtk.STOCK_REFRESH, _('Change due date...')),
-            ('PrintBill', gtk.STOCK_PRINT, _('Print bill')),
-            ('Comments', None, _('Comments...')),
-
-            ('Renegotiate', None, _('Renegotiate payments...')),
-            ('PrintReceipt', None, _('Print _receipt'), '<Control>r'),
+             group.get('add_receiving'),
+             _('Create a new account receivable')),
             ('PaymentFlowHistory', None,
-             _('Payment _flow history...'), '<Control>f'),
-
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...')),
-
-            # Search
-            ('BillCheckSearch', None, _('Bills and checks...'), '',
-             _('Search for bills and checks')),
-            ('CardPaymentSearch', None, _('Card payments...'), '',
-             _('Search for card payments')),
+             _('Payment _flow history...'),
+             group.get('payment_flow_history')),
 
             # Payment
             ('PaymentMenu', None, _('Payment')),
-
-            ('PrintToolMenu', _('Print')),
-            ('PrintList', gtk.STOCK_PRINT, _('Payment List'), '',
-             _('Print a report for this payment listing'), ),
-
-            ('Receive', gtk.STOCK_APPLY, _('Receive'), '',
+            ('Details', gtk.STOCK_INFO, _('Details...'),
+             group.get('payment_details'),
+             _('Show details for the selected payment'), ),
+            ('Receive', gtk.STOCK_APPLY, _('Receive...'),
+             group.get('payment_receive'),
              _('Receive the selected payments')),
-            ('Details', gtk.STOCK_INFO, _('Details'), '',
-             _('Show details for the selected payment'), )
+            ('CancelPayment', gtk.STOCK_REMOVE, _('Cancel payment...'),
+             group.get('payment_cancel'),
+             _('Cancel the selected payment')),
+            ('SetNotPaid', gtk.STOCK_UNDO, _('Set as not paid...'),
+             group.get('payment_set_not_paid'),
+             _('Mark the selected payment as not paid')),
+            ('ChangeDueDate', gtk.STOCK_REFRESH, _('Change due date...'),
+             group.get('payment_change_due_date'),
+             _('Change the due date of the selected payment')),
+            ('Renegotiate', None, _('Renegotiate...'),
+             group.get('payment_renegotiate'),
+             _('Renegotiate the selected payments')),
+            ('Comments', None, _('Comments...'),
+             group.get('payment_comments'),
+             _('Add comments to the selected payment')),
+            ('PrintBill', gtk.STOCK_PRINT, _('Print bill...'),
+             group.get('payment_print_bill'),
+             _('Print a bill for the selected payment')),
+            ('PrintReceipt', None, _('Print _receipt...'),
+             group.get('payment_print_receipt'),
+             _('Print a receipt for the selected payment')),
+
+            # Search
+            ('BillCheckSearch', None, _('Bills and checks...'),
+             group.get('search_bills'),
+             _('Search for bills and checks')),
+            ('CardPaymentSearch', None, _('Card payments...'),
+             group.get('search_card_payments'),
+             _('Search for card payments')),
         ]
         self.receivable_ui = self.add_ui_actions(None, actions,
                                                  filename='receivable.xml')
-        self.set_help_section(_("Accounts receivable help"), 'receber-inicio')
-
-        self.add_tool_menu_actions([
-                            ("Print", _("Print"), None,
-                            gtk.STOCK_PRINT)])
+        self.set_help_section(_("Accounts receivable help"), 'app-receivable')
 
+        self.Receive.set_short_label(_('Receive'))
+        self.Details.set_short_label(_('Details'))
         self.Receive.props.is_important = True
         self.popup = self.uimanager.get_widget('/ReceivableSelection')
 
     def create_ui(self):
-        self.search.search.search_button.hide()
         self.app.launcher.add_new_items([self.AddReceiving])
+        self.app.launcher.add_search_items([self.BillCheckSearch,
+                                            self.CardPaymentSearch])
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of this payments"))
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
-        parent = self.app.launcher.statusbar
         self.search.set_summary_label(column='value',
             label='<b>%s</b>' % (_("Total")),
             format='<b>%s</b>',
-            parent=parent)
+            parent=self.get_statusbar_message_area())
+        self.search.search.results.set_cell_data_func(
+            self._on_results__cell_data_func)
 
-    def activate(self):
+    def activate(self, params):
         self._update_widgets()
-        self.app.launcher.add_search_items([self.BillCheckSearch,
-                                            self.CardPaymentSearch])
 
-        self.search.refresh()
+        # FIXME: double negation is weird here
+        if not params.get('no-refresh'):
+            self.search.refresh()
 
     def deactivate(self):
         self.uimanager.remove_ui(self.receivable_ui)
@@ -161,14 +175,14 @@ class ReceivableApp(SearchableAppWindow):
 
     def create_filters(self):
         self.set_text_field_columns(['description', 'drawee'])
-        self.add_filter(
-            ComboSearchFilter(_('Show payments'),
-                              self._get_status_values()),
+        self.status_filter = ComboSearchFilter(_('Show payments'),
+                                               self._get_status_values())
+        self.add_filter(self.status_filter,
             SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('#'), long_title="Payment ID",
-                             width=60, data_type=int, sorted=True,
+        return [SearchColumn('id', title=_('#'), long_title=_("Payment ID"),
+                             width=60, data_type=int,
                              format='%04d'),
                 Column('color', title=_('Description'), width=20,
                        data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
@@ -180,7 +194,7 @@ class ReceivableApp(SearchableAppWindow):
                 SearchColumn('drawee', title=_('Drawee'), data_type=str,
                              ellipsize=pango.ELLIPSIZE_END, width=140),
                 SearchColumn('due_date', title=_('Due date'),
-                             data_type=datetime.date, width=100),
+                             data_type=datetime.date, width=100, sorted=True),
                 SearchColumn('paid_date', title=_('Paid date'),
                              data_type=datetime.date, width=100),
                 SearchColumn('status_str', title=_('Status'), width=100,
@@ -190,8 +204,24 @@ class ReceivableApp(SearchableAppWindow):
                 SearchColumn('value', title=_('Value'), data_type=currency,
                              width=90),
                 SearchColumn('paid_value', title=_('Paid'),
-                             long_title='Paid value',
-                             data_type=currency, width=90)]
+                             long_title=_('Paid value'),
+                             data_type=currency, width=90),
+                SearchColumn('category', title=_('Category'), data_type=str,
+                             long_title=_('Payment category'), width=110,
+                             visible=False)]
+
+    #
+    # Public API
+    #
+
+    def search_for_date(self, date):
+        self.status_filter.select(None)
+        dfilter = DateSearchFilter(_("Paid or due date"))
+        dfilter.set_removable()
+        dfilter.mode.select_item_by_position(5)
+        self.add_filter(dfilter, columns=["paid_date", "due_date"])
+        dfilter.start_date.set_date(date)
+        self.search.refresh()
 
     #
     # Private
@@ -199,15 +229,20 @@ class ReceivableApp(SearchableAppWindow):
 
     def _update_widgets(self):
         selected = self.results.get_selected_rows()
+        one_item = len(selected) == 1
         self.Receive.set_sensitive(self._can_receive(selected))
-        self.Details.set_sensitive(self._can_show_details(selected))
-        self.Comments.set_sensitive(self._can_show_comments(selected))
-        self.ChangeDueDate.set_sensitive(self._can_change_due_date(selected))
-        self.CancelPayment.set_sensitive(self._can_cancel_payment(selected))
-        self.PrintReceipt.set_sensitive(self._are_paid(selected,
-                                                       respect_sale=True))
-        self.SetNotPaid.set_sensitive(self._are_paid(selected,
-                                                     respect_sale=False))
+        self.Details.set_sensitive(
+            one_item and self._can_show_details(selected))
+        self.Comments.set_sensitive(
+            one_item and self._can_show_comments(selected))
+        self.ChangeDueDate.set_sensitive(
+            one_item and self._can_change_due_date(selected))
+        self.CancelPayment.set_sensitive(
+            one_item and self._can_cancel_payment(selected))
+        self.PrintReceipt.set_sensitive(
+            one_item and self._is_paid(selected))
+        self.SetNotPaid.set_sensitive(
+            one_item and self._is_paid(selected))
         self.PrintBill.set_sensitive(self._can_print_bill(selected))
 
     def _get_status_values(self):
@@ -246,9 +281,9 @@ class ReceivableApp(SearchableAppWindow):
                             payments=payments)
 
         if api.finish_transaction(trans, retval):
-            for view in receivable_views:
-                view.sync()
-                self.results.update(view)
+            # We need to refresh the whole list as the payment(s) can possibly
+            # disappear for the selected view
+            self.refresh()
 
         trans.close()
         self._update_widgets()
@@ -294,22 +329,16 @@ class ReceivableApp(SearchableAppWindow):
 
         trans.close()
 
-    def _are_paid(self, receivable_views, respect_sale=True):
+    def _is_paid(self, receivable_view):
         """
-        Determines if a list of receivable_views are paid.
-        To do so they must meet the following conditions:
-          - Be in the same sale
-            (This will be satistied only if respect_sale is True)
+        Determines if the selected payment is paid.
+        To do so he must meet the following condition:
           - The payment status needs to be set to PAID
         """
-        if not receivable_views:
+        if not receivable_view:
             return False
 
-        sale = receivable_views[0].sale_id
-        if sale is None and respect_sale:
-            return False
-        return all(view.sale_id == sale and view.is_paid()
-                   for view in receivable_views)
+        return receivable_view[0].is_paid()
 
     def _can_receive(self, receivable_views):
         """
@@ -416,16 +445,25 @@ class ReceivableApp(SearchableAppWindow):
     def _run_bill_check_search(self):
         run_dialog(InPaymentBillCheckSearch, self, self.conn)
 
-    def _print_payment_list(self):
-        payments = self.results.get_selected_rows() or list(self.results)
-        self.print_report(ReceivablePaymentReport, self.results, payments)
-
     #
     # Kiwi callbacks
     #
 
-    def on_results__has_rows(self, klist, has_rows):
-        self.Print.set_sensitive(has_rows)
+    def _on_results__cell_data_func(self, column, renderer, pv, text):
+        if not isinstance(renderer, gtk.CellRendererText):
+            return text
+
+        if pv.paid_date and self.status_filter.get_state().value is None:
+            renderer.set_property('strikethrough', True)
+            renderer.set_property('strikethrough-set', True)
+        else:
+            renderer.set_property('strikethrough-set', False)
+        if not pv.paid_date and pv.due_date < datetime.datetime.now():
+            renderer.set_property('weight', pango.WEIGHT_BOLD)
+            renderer.set_property('weight-set', True)
+        else:
+            renderer.set_property('weight-set', False)
+        return text
 
     def on_results__row_activated(self, klist, receivable_view):
         self._show_details(receivable_view)
@@ -443,22 +481,17 @@ class ReceivableApp(SearchableAppWindow):
     def on_Receive__activate(self, button):
         self._receive(self.results.get_selected_rows())
 
-    def on_Print__activate(self, button):
-        self._print_payment_list()
-
-    def on_PrintList__activate(self, action):
-        self._print_payment_list()
-
     def on_Comments__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
         self._show_comments(receivable_view)
 
     def on_PrintReceipt__activate(self, action):
         register_payment_operations()
-        receivable_views = self.results.get_selected_rows()
-        payments = [v.payment for v in receivable_views]
-        print_report(ReceivalReceipt, payments=payments,
-                     sale=receivable_views[0].sale)
+        receivable_view = self.results.get_selected_rows()[0]
+        payment = receivable_view.payment
+        date = datetime.date.today()
+        print_report(InPaymentReceipt, payment=payment,
+                     order=receivable_view.sale, date=date)
 
     def on_PaymentFlowHistory__activate(self, action):
         self.run_dialog(PaymentFlowHistoryDialog, self.conn)
@@ -502,9 +535,8 @@ class ReceivableApp(SearchableAppWindow):
             self.search.refresh()
 
     def on_PrintBill__activate(self, action):
-        if not can_generate_bill():
-            return
-
-        item = self.results.get_selected_rows()[0]
-        payment = item.payment
-        print_report(BillReport, [payment])
+        items = self.results.get_selected_rows()
+        payments = [item.payment for item in items]
+        if not BillReport.check_printable(payments):
+            return False
+        print_report(BillReport, payments)
