@@ -38,6 +38,8 @@ from stoqlib.api import api
 from stoqlib.domain.invoice import InvoicePrinter
 from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.gui.editors.invoiceeditor import SaleInvoicePrinterDialog
+from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.search.callsearch import ClientCallsSearch
 from stoqlib.gui.search.commissionsearch import CommissionSearch
 from stoqlib.gui.search.loansearch import LoanItemSearch, LoanSearch
 from stoqlib.gui.search.personsearch import ClientSearch
@@ -45,11 +47,14 @@ from stoqlib.gui.search.productsearch import ProductSearch
 from stoqlib.gui.search.salesearch import DeliverySearch, SoldItemsByBranchSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.slaves.saleslave import SaleListToolbar
+from stoqlib.gui.stockicons import (STOQ_PRODUCTS, STOQ_SERVICES,
+                                    STOQ_CLIENTS, STOQ_DELIVERY)
 from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
 from stoqlib.gui.wizards.salequotewizard import SaleQuoteWizard
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.invoice import SaleInvoice, print_sale_invoice
 from stoqlib.lib.message import info, yesno
+from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
 
@@ -60,10 +65,10 @@ _ = gettext.gettext
 class SalesApp(SearchableAppWindow):
 
     app_name = _('Sales')
-    app_icon_name = 'stoq-sales-app'
     gladefile = 'sales_app'
     search_table = SaleView
     search_label = _('matching:')
+    report_table = SalesReport
     embedded = True
 
     cols_info = {Sale.STATUS_INITIAL: 'open_date',
@@ -84,48 +89,52 @@ class SalesApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.sales')
         actions = [
-            ('menubar', None, ''),
-
-            # Sales
-            ("SalesMenu", None, _("_Sales")),
+            # File
             ("SaleQuote", None, _("Sale quote..."), '',
              _('Create a new quote for a sale')),
-            ("SalesCancel", None, _("Cancel quote")),
-            ("SalesPrintInvoice", gtk.STOCK_PRINT,
-             _("_Print invoice...")),
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...'),
-             '<Control>F10'),
-
-            # Loan
-            ("LoanMenu", None, _("_Loan")),
-            ("LoanNew", None, _("New loan...")),
+            ("LoanNew", None, _("Loan...")),
             ("LoanClose", None, _("Close loan...")),
-            ("LoanSearch", None, _("Search loans...")),
-            ("LoanSearchItems", None, _("Search loan items...")),
 
             # Search
             ("SearchSoldItemsByBranch", None, _("Sold items by branch..."),
-             "<Control><Alt>a", _("Search for sold items by branch")),
-            ("SearchProduct", 'stoq-products', _("Products..."),
-             "<Control><Alt>p", _("Search for products")),
-            ("SearchService", 'stoq-services', _("Services..."),
-             "<Control><Alt>s", _("Search for services")),
-            ("SearchDelivery", 'stoq-delivery', _("Deliveries..."),
-             "<Control><Alt>e", _("Search for deliveries")),
-            ("SearchClient", 'stoq-clients', _("Clients..."),
-             "<Control><Alt>c", _("Search for clients")),
+             group.get("search_sold_items_by_branch"),
+             _("Search for sold items by branch")),
+            ("SearchProduct", STOQ_PRODUCTS, _("Products..."),
+             group.get("search_products"),
+             _("Search for products")),
+            ("SearchService", STOQ_SERVICES, _("Services..."),
+             group.get("search_services"),
+             _("Search for services")),
+            ("SearchDelivery", STOQ_DELIVERY, _("Deliveries..."),
+             group.get("search_deliveries"),
+             _("Search for deliveries")),
+            ("SearchClient", STOQ_CLIENTS, _("Clients..."),
+             group.get("search_clients"),
+             _("Search for clients")),
+            ("SearchClientCalls", None, _("Client Calls..."),
+             group.get("search_client_calls"),
+             _("Search for client calls")),
             ("SearchCommission", None, _("Commissions..."),
-             "<Control><Alt>o", _("Search for salespersons commissions")),
+             group.get("search_commissions"),
+             _("Search for salespersons commissions")),
+            ("LoanSearch", None, _("Loans..."),
+             group.get("search_loans")),
+            ("LoanSearchItems", None, _("Loan items..."),
+             group.get("search_loan_items")),
 
-            ("Print", gtk.STOCK_PRINT, _("Print"), '',
-             _("Print a report for this sale listing")),
-            ("Return", gtk.STOCK_CANCEL, _("Return sale"), '',
+            # Sale
+            ("SaleMenu", None, _("Sale")),
+
+            ("SalesCancel", None, _("Cancel quote...")),
+            ("SalesPrintInvoice", gtk.STOCK_PRINT, _("_Print invoice...")),
+            ("Return", gtk.STOCK_CANCEL, _("Return..."), '',
              _("Return the selected sale, canceling it's payments")),
-            ("Edit", gtk.STOCK_EDIT, _("Edit"), '',
+            ("Edit", gtk.STOCK_EDIT, _("Edit..."), '',
              _("Edit the selected sale, allowing you to change the details "
                "of it")),
-            ("Details", gtk.STOCK_INFO, _("Details"), '',
+            ("Details", gtk.STOCK_INFO, _("Details..."), '',
              _("Show details of the selected sale"))
         ]
 
@@ -137,10 +146,15 @@ class SalesApp(SearchableAppWindow):
         self.SearchProduct.set_short_label(_("Products"))
         self.SearchService.set_short_label(_("Services"))
         self.SearchDelivery.set_short_label(_("Deliveries"))
+        self.SalesCancel.set_short_label(_("Cancel"))
+        self.Edit.set_short_label(_("Edit"))
+        self.Return.set_short_label(_("Return"))
+        self.Details.set_short_label(_("Details"))
 
-        self.set_help_section(_("Sales help"), 'vendas-inicio')
+        self.set_help_section(_("Sales help"), 'app-sales')
 
     def create_ui(self):
+        self.popup = self.uimanager.get_widget('/SaleSelection')
 
         self._columns = self.get_columns()
         self._setup_columns()
@@ -152,10 +166,9 @@ class SalesApp(SearchableAppWindow):
           self.SearchClient,
           self.SearchService,
           self.SearchDelivery])
+        self.app.launcher.Print.set_tooltip(_("Print a report of these sales"))
 
-    def activate(self):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.Print.set_sensitive(False)
+    def activate(self, params):
         self.check_open_inventory()
         self._update_toolbar()
 
@@ -230,11 +243,10 @@ class SalesApp(SearchableAppWindow):
     #
 
     def _create_summary_label(self):
-        parent = self.app.launcher.statusbar
         self.search.set_summary_label(column='total',
                                       label='<b>Total:</b>',
                                       format='<b>%s</b>',
-                                      parent=parent)
+                                      parent=self.get_statusbar_message_area())
 
     def _setup_widgets(self):
         self._setup_slaves()
@@ -355,9 +367,11 @@ class SalesApp(SearchableAppWindow):
         self._update_toolbar()
 
     def on_results__has_rows(self, results, has_rows):
-        self.Print.set_sensitive(has_rows)
         self._update_toolbar()
 
+    def on_results__right_click(self, results, result, event):
+        self.popup.popup(None, None, None, event.button, event.time)
+
     # Sales
 
     def on_SaleQuote__activate(self, action):
@@ -412,6 +426,9 @@ class SalesApp(SearchableAppWindow):
     def on_SearchCommission__activate(self, button):
         self.run_dialog(CommissionSearch, self.conn)
 
+    def on_SearchClientCalls__activate(self, action):
+        self.run_dialog(ClientCallsSearch, self.conn)
+
     def on_SearchService__activate(self, button):
         self.run_dialog(ServiceSearch, self.conn, hide_toolbar=True)
 
@@ -423,9 +440,6 @@ class SalesApp(SearchableAppWindow):
 
     # Toolbar
 
-    def on_Print__activate(self, action):
-        self.sale_toolbar.print_sale()
-
     def on_Edit__activate(self, action):
         self.sale_toolbar.edit()
 
