@@ -41,11 +41,11 @@ from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import ProductFullStockView
 from stoqlib.lib.defaults import sort_sellable_code
 from stoqlib.lib.message import warning
+from stoqlib.gui.dialogs.initialstockdialog import InitialStockDialog
+from stoqlib.gui.dialogs.productstockdetails import ProductStockHistoryDialog
+from stoqlib.gui.dialogs.productimage import ProductImageViewer
 from stoqlib.gui.editors.producteditor import ProductStockEditor
-from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
-from stoqlib.gui.wizards.receivingwizard import ReceivingOrderWizard
-from stoqlib.gui.wizards.stocktransferwizard import StockTransferWizard
-from stoqlib.gui.wizards.stockdecreasewizard import StockDecreaseWizard
+from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.loansearch import LoanItemSearch, LoanSearch
 from stoqlib.gui.search.receivingsearch import PurchaseReceivingSearch
 from stoqlib.gui.search.productsearch import (ProductSearchQuantity,
@@ -54,10 +54,12 @@ from stoqlib.gui.search.productsearch import (ProductSearchQuantity,
 from stoqlib.gui.search.purchasesearch import PurchasedItemsSearch
 from stoqlib.gui.search.transfersearch import TransferOrderSearch
 from stoqlib.gui.search.stockdecreasesearch import StockDecreaseSearch
-from stoqlib.gui.dialogs.initialstockdialog import InitialStockDialog
-from stoqlib.gui.dialogs.productstockdetails import ProductStockHistoryDialog
-from stoqlib.gui.dialogs.productimage import ProductImageViewer
+from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
+from stoqlib.gui.wizards.receivingwizard import ReceivingOrderWizard
+from stoqlib.gui.wizards.stocktransferwizard import StockTransferWizard
+from stoqlib.gui.wizards.stockdecreasewizard import StockDecreaseWizard
 from stoqlib.reporting.product import SimpleProductReport
+from stoqlib.gui.stockicons import STOQ_RECEIVING
 
 from stoq.gui.application import SearchableAppWindow
 
@@ -67,10 +69,10 @@ log = Logger('stoq.gui.stock')
 
 class StockApp(SearchableAppWindow):
     app_name = _('Stock')
-    app_icon_name = 'stoq-stock-app'
     gladefile = "stock"
     search_table = ProductFullStockView
     search_labels = _('Matching:')
+    report_table = SimpleProductReport
     pixbuf_converter = converter.get_converter(gtk.gdk.Pixbuf)
     embedded = True
 
@@ -79,70 +81,69 @@ class StockApp(SearchableAppWindow):
     #
 
     def create_actions(self):
+        group = get_accels('app.stock')
         actions = [
-            ('menubar', None, ''),
-
-            # Stock
-            ("StockMenu", None, _("_Stock")),
-            ("NewReceiving", 'stoq-receiving', _("_Receive order..."),
-             '<Control>r'),
-            ('NewTransfer', 'gtk-convert', _('Transfer...'), '<Control>t'),
-            ('NewStockDecrease', None, _('Decrease stock...')),
-            ('StockInitial', 'gtk-go-up', _('Register initial stock...')),
-            ('ExportCSV', gtk.STOCK_SAVE_AS, _('Export CSV...'), '<Control>F10'),
-
-            # Loan
-            ("LoanMenu", None, _("_Loan")),
-            ("LoanNew", None, _("New loan...")),
+            ("NewReceiving", STOQ_RECEIVING, _("Order _receival..."),
+             group.get('new_receiving')),
+            ('NewTransfer', gtk.STOCK_CONVERT, _('Transfer...'),
+             group.get('transfer_product')),
+            ('NewStockDecrease', None, _('Stock decrease...')),
+            ('StockInitial', gtk.STOCK_GO_UP, _('Register initial stock...')),
+            ("LoanNew", None, _("Loan...")),
             ("LoanClose", None, _("Close loan...")),
-            ("LoanSearch", None, _("Search loans...")),
-            ("LoanSearchItems", None, _("Search loan items...")),
-
-            # Search
             ("SearchPurchaseReceiving", None, _("Received purchases..."),
-             "<Control><Alt>u", _("Search for received purchase orders")),
+             group.get('search_receiving'),
+             _("Search for received purchase orders")),
             ("SearchProductHistory", None, _("Product history..."),
-             "<Control><Alt>p", _("Search for product history")),
+             group.get('search_product_history'),
+             _("Search for product history")),
             ("SearchStockDecrease", None, _("Stock decreases..."), '',
              _("Search for manual stock decreases")),
             ("SearchPurchasedStockItems", None, _("Purchased items..."),
-             "<Control><Alt>i", _("Search for purchased items")),
-            ("SearchStockItems", None, _("Stock items..."), "<Control><Alt>s",
+             group.get('search_purchased_stock_items'),
+             _("Search for purchased items")),
+            ("SearchStockItems", None, _("Stock items..."),
+             group.get('search_stock_items'),
              _("Search for items on stock")),
-            ("SearchTransfer", None, _("Transfers..."), "<Control><Alt>t",
+            ("SearchTransfer", None, _("Transfers..."),
+             group.get('search_transfers'),
              _("Search for stock transfers")),
             ("SearchClosedStockItems", None, _("Closed stock Items..."),
-             "<Control><Alt>c", _("Search for closed stock items")),
-
-             # Toolbar
-            ("Print", gtk.STOCK_PRINT, _("Print"), '',
-            _('Print a report of this products listing')),
-            ("ProductStockHistory", gtk.STOCK_INFO, _("History"), '',
+             group.get('search_closed_stock_items'),
+             _("Search for closed stock items")),
+            ("LoanSearch", None, _("Loans...")),
+            ("LoanSearchItems", None, _("Loan items...")),
+            ("ProductMenu", None, _("Product")),
+            ("ProductStockHistory", gtk.STOCK_INFO, _("History..."),
+             group.get('history'),
             _('Show the stock history of the selected product')),
-            ("EditProduct", gtk.STOCK_EDIT, _("Edit"), '',
+            ("EditProduct", gtk.STOCK_EDIT, _("Edit..."),
+             group.get('edit_product'),
             _("Edit the selected product, allowing you to change it's "
               "details")),
         ]
         self.stock_ui = self.add_ui_actions('', actions,
                                             filename='stock.xml')
 
-        toogle_actions = [
+        toggle_actions = [
             ('StockPictureViewer', None, _('Picture viewer'),
-             '<Control><Alt>v'),
+             group.get('toggle_picture_viewer')),
         ]
-        self.add_ui_actions('', toogle_actions, 'ToogleActions',
-                            'toogle')
-        self.set_help_section(_("Stock help"), 'vendas-inicio')
+        self.add_ui_actions('', toggle_actions, 'ToggleActions',
+                            'toggle')
+        self.set_help_section(_("Stock help"), 'app-stock')
 
         self.NewReceiving.set_short_label(_("Receive"))
         self.NewTransfer.set_short_label(_("Transfer"))
+        self.EditProduct.set_short_label(_("Edit"))
+        self.ProductStockHistory.set_short_label(_("History"))
         self.EditProduct.props.is_important = True
         self.ProductStockHistory.props.is_important = True
 
     def create_ui(self):
         self.popup = self.uimanager.get_widget('/StockSelection')
         self.app.launcher.add_new_items([self.NewReceiving, self.NewTransfer,
-                                         self.NewStockDecrease])
+                                         self.NewStockDecrease, self.LoanNew])
         self.app.launcher.add_search_items([
             self.SearchStockItems,
             self.SearchStockDecrease,
@@ -151,6 +152,8 @@ class StockApp(SearchableAppWindow):
             self.SearchPurchasedStockItems,
             self.SearchTransfer,
             ])
+        self.app.launcher.Print.set_tooltip(
+            _("Print a report of these products"))
         self._inventory_widgets = [self.NewTransfer, self.NewReceiving,
                                    self.StockInitial, self.NewStockDecrease,
                                    self.LoanNew, self.LoanClose]
@@ -164,16 +167,12 @@ class StockApp(SearchableAppWindow):
         self.edit_button.set_icon_widget(self.image)
         self.image.show()
 
-        parent = self.app.launcher.statusbar
         self.search.set_summary_label(column='stock',
                                       label=_('<b>Stock Total:</b>'),
                                       format='<b>%s</b>',
-                                      parent=parent)
-        self.search.search.search_button.hide()
+                                      parent=self.get_statusbar_message_area())
 
-    def activate(self):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.Print.set_sensitive(False)
+    def activate(self, params):
         self.app.launcher.NewToolItem.set_tooltip(
             _("Create a new receiving order"))
         self.app.launcher.SearchToolItem.set_tooltip(
@@ -200,6 +199,11 @@ class StockApp(SearchableAppWindow):
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
+    def print_report(self, *args, **kwargs):
+        # SimpleProductReport needs a branch_name kwarg
+        kwargs['branch_name'] = self.branch_filter.combo.get_active_text()
+        super(StockApp, self).print_report(*args, **kwargs)
+
     #
     # SearchableAppWindow
     #
@@ -257,8 +261,6 @@ class StockApp(SearchableAppWindow):
         branch = api.get_current_branch(self.conn)
 
         is_main_branch = self.branch_filter.get_state().value is branch
-        has_stock = len(self.results) > 0
-
         item = self.results.get_selected()
 
         pixbuf = None
@@ -283,12 +285,11 @@ class StockApp(SearchableAppWindow):
         if pixbuf:
             self.image.set_from_pixbuf(pixbuf)
         else:
-            self.image.set_from_stock('gtk-edit', gtk.ICON_SIZE_LARGE_TOOLBAR)
+            self.image.set_from_stock(gtk.STOCK_EDIT, gtk.ICON_SIZE_LARGE_TOOLBAR)
 
         self.set_sensitive([self.EditProduct], bool(item))
         self.set_sensitive([self.ProductStockHistory],
                            bool(item) and is_main_branch)
-        self.set_sensitive([self.Print], has_stock)
         # We need more than one branch to be able to do transfers
         # Note that 'all branches' is not a real branch
         has_branches = len(self.branch_filter.combo) > 2
@@ -308,6 +309,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(StockTransferWizard, trans)
         api.finish_transaction(trans, model)
         trans.close()
+        self.search.refresh()
 
     def _receive_purchase(self):
         if self.check_open_inventory():
@@ -316,6 +318,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(ReceivingOrderWizard, trans)
         api.finish_transaction(trans, model)
         trans.close()
+        self.search.refresh()
 
     #
     # Callbacks
@@ -333,11 +336,6 @@ class StockApp(SearchableAppWindow):
     def on_results__right_click(self, results, result, event):
         self.popup.popup(None, None, None, event.button, event.time)
 
-    def on_Print__activate(self, button):
-        branch_name = self.branch_filter.combo.get_active_text()
-        self.print_report(SimpleProductReport, self.results,
-                          list(self.results), branch_name=branch_name)
-
     def on_ProductStockHistory__activate(self, button):
         selected = self.results.get_selected()
         sellable = Sellable.get(selected.id, connection=self.conn)
@@ -370,12 +368,14 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(StockDecreaseWizard, trans)
         api.finish_transaction(trans, model)
         trans.close()
+        self.search.refresh()
 
     def on_StockInitial__activate(self, action):
         if self.check_open_inventory():
             return
         branch = self.branch_filter.get_state().value
         self.run_dialog(InitialStockDialog, self.conn, branch)
+        self.search.refresh()
 
     def on_StockPictureViewer__activate(self, button):
         if self.image_viewer:
@@ -401,6 +401,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(NewLoanWizard, trans)
         api.finish_transaction(trans, model)
         trans.close()
+        self.search.refresh()
 
     def on_LoanClose__activate(self, action):
         if self.check_open_inventory():
@@ -409,6 +410,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(CloseLoanWizard, trans)
         api.finish_transaction(trans, model)
         trans.close()
+        self.search.refresh()
 
     def on_LoanSearch__activate(self, action):
         self.run_dialog(LoanSearch, self.conn)
