@@ -25,6 +25,7 @@
 """ Listing and importing applications """
 
 import gettext
+import platform
 
 from kiwi.component import implements
 from stoqlib.lib.interfaces import IApplicationDescriptions
@@ -77,6 +78,9 @@ _APPLICATIONS = {
              STOQ_TILL_APP),
 }
 
+if platform.system() == 'Windows':
+    del _APPLICATIONS['calendar']
+
 
 def get_application_names():
     """Get a list of application names, useful for launcher programs
