@@ -43,12 +43,12 @@ from stoqlib.domain.profile import UserProfile
 from stoqlib.domain.profile import ProfileSettings
 from stoqlib.exceptions import (DatabaseError, StoqlibError,
                                 DatabaseInconsistency)
+from stoqlib.lib.configparser import register_config, StoqConfig
 from stoqlib.lib.crashreport import collect_traceback
 from stoqlib.lib.interfaces import  IApplicationDescriptions
 from stoqlib.lib.message import error
 from stoqlib.lib.osutils import read_registry_key
 
-from stoq.lib.configparser import register_config, StoqConfig
 from stoq.lib.options import get_option_parser
 
 _ = gettext.gettext
@@ -104,7 +104,6 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
     # NOTE: No GUI calls are allowed in here
     #       If you change anything here, you need to verify that all
     #       callsites are still working properly.
-    #       bin/debug
     #       bin/stoq
     #       bin/stoqdbadmin
     #       python stoq/tests/runtest.py
@@ -176,6 +175,9 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
         if options.sqldebug:
             orm_enable_debugging()
 
+    from stoqlib.gui.keybindings import load_user_keybindings
+    load_user_keybindings()
+
 
 def needs_schema_update():
     try:
