@@ -33,12 +33,15 @@ from contextlib import contextmanager
 from kiwi.component import get_utility
 from twisted.internet.defer import inlineCallbacks, returnValue
 
-from stoqlib.lib.parameters import sysparam, is_developer_mode
-from stoqlib.lib.interfaces import IStoqConfig
+from stoqlib.database.interfaces import IDatabaseSettings
 from stoqlib.database.runtime import (get_connection, new_transaction,
                                       rollback_and_begin, finish_transaction)
 from stoqlib.database.runtime import (get_current_branch,
                                       get_current_station, get_current_user)
+from stoqlib.lib.settings import get_settings
+from stoqlib.lib.interfaces import IStoqConfig
+from stoqlib.lib.parameters import sysparam, is_developer_mode
+from stoqlib.l10n.l10n import get_l10n_field
 
 
 class StoqAPI(object):
@@ -98,6 +101,14 @@ class StoqAPI(object):
     def config(self):
         return get_utility(IStoqConfig)
 
+    @property
+    def db_settings(self):
+        return get_utility(IDatabaseSettings)
+
+    @property
+    def user_settings(self):
+        return get_settings()
+
     def sysparam(self, conn):
         return sysparam(conn)
 
@@ -123,4 +134,7 @@ class StoqAPI(object):
     def asyncReturn(self, value=None):
         return returnValue(value)
 
+    def get_l10n_field(self, conn, field_name):
+        return get_l10n_field(conn, field_name)
+
 api = StoqAPI()
