@@ -35,7 +35,6 @@ from stoqlib.domain.interfaces import (IBranch, ICompany, IEmployee,
                                        IIndividual, ISupplier,
                                        IStorable, ISalesPerson,
                                        IClient, IUser, ITransporter,
-                                       IBankBranch,
                                        ICreditProvider)
 from stoqlib.lib.parameters import sysparam
 
@@ -166,10 +165,6 @@ def create_client_category_price(trans):
     return ExampleCreator.create(trans, 'ClientCategoryPrice')
 
 
-def create_bank(trans):
-    return ExampleCreator.create(trans, 'Bank')
-
-
 def create_bank_account(trans):
     return ExampleCreator.create(trans, 'BankAccount')
 
@@ -203,9 +198,7 @@ class ExampleCreator(object):
             'PaymentMethod': self.get_payment_method,
             'Sellable': self.create_sellable,
             'PaymentGroup': self.create_payment_group,
-            'BaseSellableInfo': self.create_base_sellable_info,
             'BranchStation': self.get_station,
-            'Bank': self.create_bank,
             'CityLocation': self.get_location,
             'CfopData': self.create_cfop_data,
             'ClientCategory': self.create_client_category,
@@ -223,11 +216,9 @@ class ExampleCreator(object):
             'ISupplier': self.create_supplier,
             'ITransporter': self.create_transporter,
             'IUser': self.create_user,
-            'OnSaleInfo': self.create_on_sale_info,
             'Payment': self.create_payment,
             'ParameterData': self.create_parameter_data,
             'Person': self.create_person,
-            'PersonAdaptToBankBranch': self.create_bank_branch,
             'PersonAdaptToBranch': self.create_branch,
             'PersonAdaptToCompany': self.create_company,
             'PersonAdaptToClient': self.create_client,
@@ -268,7 +259,6 @@ class ExampleCreator(object):
             'PaymentCategory': self.create_payment_category,
             'FiscalDayHistory': self.create_fiscal_day_history,
             'Calls': self.create_call,
-            'Bank': self.create_bank,
             'BankAccount': self.create_bank_account,
             'QuoteGroup': self.create_quote_group,
             'Quotation': self.create_quotation,
@@ -370,24 +360,16 @@ class ExampleCreator(object):
                                 component=component,
                                 connection=self.trans)
 
-    def create_base_sellable_info(self, price=None):
-        from stoqlib.domain.sellable import BaseSellableInfo
-        if price is None:
-            price = 10
-        return BaseSellableInfo(connection=self.trans,
-                                description="Description",
-                                price=price)
-
     def create_sellable(self, price=None):
         from stoqlib.domain.product import Product
         from stoqlib.domain.sellable import Sellable
         tax_constant = sysparam(self.trans).DEFAULT_PRODUCT_TAX_CONSTANT
-        base_sellable_info = self.create_base_sellable_info(price=price)
-        on_sale_info = self.create_on_sale_info()
+        if price is None:
+            price = 10
         sellable = Sellable(cost=125,
                             tax_constant=tax_constant,
-                            base_sellable_info=base_sellable_info,
-                            on_sale_info=on_sale_info,
+                            price=price,
+                            description="Description",
                             connection=self.trans)
         Product(sellable=sellable, connection=self.trans)
         return sellable
@@ -653,11 +635,11 @@ class ExampleCreator(object):
     def create_service(self):
         from stoqlib.domain.sellable import Sellable, SellableTaxConstant
         from stoqlib.domain.service import Service
-        sellable_info = self.create_base_sellable_info()
         tax_constant = SellableTaxConstant.get_by_type(
             TaxType.SERVICE, self.trans)
         sellable = Sellable(tax_constant=tax_constant,
-                            base_sellable_info=sellable_info,
+                            price=10,
+                            description="Description",
                             connection=self.trans)
         service = Service(sellable=sellable, connection=self.trans)
         return service
@@ -675,23 +657,13 @@ class ExampleCreator(object):
         person.addFacet(ICompany, connection=self.trans)
         return person.addFacet(ITransporter, connection=self.trans)
 
-    def create_bank(self):
-        from stoqlib.domain.account import Bank
-        return Bank(connection=self.trans, name='Boston', short_name='short',
-                    compensation_code='1234')
-
-    def create_bank_account(self):
+    def create_bank_account(self, account=None):
         from stoqlib.domain.account import BankAccount
         return BankAccount(connection=self.trans,
-                           bank_id=1,
-                           branch='2666-1',
-                           account='20.666-1')
-
-    def create_bank_branch(self):
-        person = self.create_person()
-        person.addFacet(ICompany, connection=self.trans)
-        return person.addFacet(IBankBranch, connection=self.trans,
-                               bank=self.create_bank())
+                           bank_branch='2666-1',
+                           bank_account='20.666-1',
+                           bank_number=1,
+                           account=account or self.create_account())
 
     def create_credit_provider(self):
         person = self.create_person()
@@ -718,10 +690,6 @@ class ExampleCreator(object):
         from stoqlib.domain.payment.group import PaymentGroup
         return PaymentGroup(connection=self.trans)
 
-    def create_on_sale_info(self):
-        from stoqlib.domain.sellable import OnSaleInfo
-        return OnSaleInfo(connection=self.trans)
-
     def create_sellable_tax_constant(self):
         from stoqdrivers.enum import TaxType
         from stoqlib.domain.sellable import SellableTaxConstant
