@@ -148,17 +148,15 @@ class Payment(Domain):
         return self.comments.count()
 
     @property
-    def bank(self):
-        """Get a BankAccount instance
-        @returns: a BankAccount instance, if the payment method does not
-        provide a bank account.
-        """
-        # This is mainly used by receipt.rml, and is a convenience
+    def bank_account_number(self):
+        # This is used by test_payment_method, and is a convenience
         # property, ideally we should move it to payment operation
         # somehow
         if self.method.method_name == 'check':
             data = self.method.operation.get_check_data_by_payment(self)
-            return data.bank_data
+            bank_account = data.bank_account
+            if bank_account:
+                return bank_account.bank_number
 
     def get_status_str(self):
         if not self.status in self.statuses:
@@ -219,7 +217,8 @@ class Payment(Domain):
         from stoqlib.domain.payment.operation import register_payment_operations
         register_payment_operations()
 
-        if self.method.operation.create_transaction():
+        if (self.is_separate_payment() or
+            self.method.operation.create_transaction()):
             AccountTransaction.create_from_payment(self, account)
 
         if self.value == self.paid_value:
@@ -378,6 +377,37 @@ class Payment(Domain):
             return self.open_date.date().strftime('%x')
         return ""
 
+    def get_payment_number_str(self):
+        return u'%05d' % self.id
+
+    def is_inpayment(self):
+        """Find out if a payment is incoming
+        @returns: True if it's incoming"""
+        return IInPayment(self, None) is not None
+
+    def is_outpayment(self):
+        """Find out if a payment is outgoing
+        @returns: True if it's outgoing"""
+        return IOutPayment(self, None) is not None
+
+    def is_separate_payment(self):
+        # FIXME: This is a hack, we should rather store a flag
+        #        in the database that tells us how the payment was
+        #        created.
+        group = self.group
+        if not group:
+            # Should never happen
+            return False
+
+        if group.sale:
+            return False
+        elif group.purchase:
+            return False
+        elif group._renegotiation:
+            return False
+
+        return True
+
 
 class PaymentChangeHistory(Domain):
     """ A class to hold information about changes to a payment.
@@ -509,7 +539,7 @@ class PaymentFlowHistory(Domain):
         else:
             payment_qty = -1
 
-        if IOutPayment(payment, None) is not None:
+        if payment.is_outpayment():
             if accomplished:
                 self.paid += value
                 self.paid_payments += payment_qty
@@ -521,7 +551,7 @@ class PaymentFlowHistory(Domain):
                     to_pay = 0
                 self.to_pay = to_pay
                 self.to_pay_payments += payment_qty
-        elif IInPayment(payment, None) is not None:
+        elif payment.is_inpayment():
             if accomplished:
                 self.received += value
                 self.received_payments += payment_qty
@@ -662,7 +692,6 @@ class PaymentFlowHistory(Domain):
         day_history._update_registers(payment, -payment.paid_value,
                                       accomplished=True)
 
-
 #
 # Payment adapters
 #
