@@ -30,7 +30,6 @@ facets (adapters).
 There are currently the following Person facets available:
 
   - Branch
-  - BankBranch
   - Client
   - Company
   - CreditProvider
@@ -81,7 +80,7 @@ from stoqlib.domain.base import Domain, ModelAdapter
 from stoqlib.domain.event import Event
 from stoqlib.domain.interfaces import (IIndividual, ICompany, IEmployee,
                                        IClient, ISupplier, IUser, IBranch,
-                                       ISalesPerson, IBankBranch, IActive,
+                                       ISalesPerson, IActive,
                                        ICreditProvider, ITransporter,
                                        IDescribable, IPersonFacet)
 from stoqlib.domain.payment.payment import Payment
@@ -870,16 +869,6 @@ class PersonAdaptToBranch(PersonAdapter):
 Person.registerFacet(PersonAdaptToBranch, IBranch)
 
 
-class PersonAdaptToBankBranch(PersonAdapter):
-    """A bank branch facet of a person."""
-    implements(IBankBranch)
-
-    is_active = BoolCol(default=True)
-    bank = ForeignKey('Bank')
-
-Person.registerFacet(PersonAdaptToBankBranch, IBankBranch)
-
-
 class PersonAdaptToCreditProvider(PersonAdapter):
     """A credit provider facet of a person."""
     implements(ICreditProvider)
@@ -1345,3 +1334,15 @@ class CallsView(Viewable):
                 query = date_query
 
         return cls.select(query, having=having, connection=connection)
+
+    @classmethod
+    def select_by_date(cls, date, connection):
+        return cls.select_by_client_date(None, None, date,
+                                         connection=connection)
+
+
+class ClientCallsView(CallsView):
+    joins = CallsView.joins[:]
+    joins.append(
+        INNERJOINOn(None, PersonAdaptToClient,
+                    PersonAdaptToClient.q.originalID == Person.q.id))
