@@ -96,7 +96,7 @@ class BranchDialog(BaseEditor):
     def _setup_widgets(self):
         self.name.grab_focus()
         self.document_l10n = api.get_l10n_field(self.conn, 'company_document')
-        self.cnp_lbl.set_label(self.document_l10n.label)
+        self.cnpj_lbl.set_label(self.document_l10n.label)
         self.cnpj.set_mask(self.document_l10n.entry_mask)
 
     def _setup_slaves(self):
