@@ -39,7 +39,7 @@ from stoqlib.domain.person import PersonAdaptToSupplier
 from stoqlib.domain.product import (ProductSupplierInfo, Product,
                                     ProductComponent,
                                     ProductQualityTest)
-from stoqlib.domain.sellable import (BaseSellableInfo, Sellable,
+from stoqlib.domain.sellable import (Sellable,
                                      SellableTaxConstant)
 from stoqlib.domain.views import ProductFullStockView
 from stoqlib.gui.base.dialogs import run_dialog
@@ -182,11 +182,7 @@ class ProductComponentSlave(BaseEditorSlave):
 
         # FIXME: This is wrong. Summary label already calculates the total. We
         # are duplicating this.
-        value = 0
-        for component in self.component_tree:
-            if self.component_tree.get_parent(component):
-                continue
-            value += component.get_total_production_cost()
+        value = self.get_component_cost()
         self.component_label.set_value(get_formatted_cost(value))
 
     def _populate_component_tree(self):
@@ -312,7 +308,12 @@ class ProductComponentSlave(BaseEditorSlave):
         return len(self.component_tree) > 0
 
     def get_component_cost(self):
-        return sum([c.get_total_production_cost() for c in self.component_tree])
+        value = 0
+        for component in self.component_tree:
+            if self.component_tree.get_parent(component):
+                continue
+            value += component.get_total_production_cost()
+        return value
 
     #
     # Kiwi Callbacks
@@ -583,6 +584,8 @@ class ProductComponentEditor(BaseEditor):
 class ProductEditor(SellableEditor):
     model_name = _('Product')
     model_type = Product
+    help_section = 'product'
+    ui_form_name = 'product'
 
     _model_created = False
 
@@ -618,7 +621,8 @@ class ProductEditor(SellableEditor):
     #
 
     def setup_slaves(self):
-        details_slave = ProductDetailsSlave(self.conn, self.model.sellable)
+        details_slave = ProductDetailsSlave(self.conn, self.model.sellable,
+                                            self.db_form)
         self.add_extra_tab(_(u'Details'), details_slave)
 
         for tabname, tabslave in self.get_extra_tabs():
@@ -645,10 +649,8 @@ class ProductEditor(SellableEditor):
 
     def create_model(self, conn):
         self._model_created = True
-        sellable_info = BaseSellableInfo(connection=conn)
         tax_constant = sysparam(conn).DEFAULT_PRODUCT_TAX_CONSTANT
-        sellable = Sellable(base_sellable_info=sellable_info,
-                            tax_constant=tax_constant,
+        sellable = Sellable(tax_constant=tax_constant,
                             connection=conn)
         sellable.unit = sysparam(self.conn).SUGGESTED_UNIT
         model = Product(connection=conn, sellable=sellable)
