@@ -529,6 +529,14 @@ _details = [
         _('If Stoq is used in a demonstration mode'),
         bool, initial=False),
 
+    ParameterDetails(
+        'BLOCK_INCOMPLETE_PURCHASE_PAYMENTS',
+        _('Payments'),
+        _('Block incomplete purchase payments'),
+        _('Do not allow confirming a account payable if the purchase is not '
+          'completely received.'),
+        bool, initial=False),
+
     # This parameter is tricky, we want to ask the user to fill it in when
     # upgrading from a previous version, but not if the user installed Stoq
     # from scratch. Some of the hacks involved with having 3 boolean values
@@ -541,6 +549,18 @@ _details = [
         _('If online services such as upgrade notifications, automatic crash reports '
           'should be enabled.'),
         bool, initial=True, onupgrade=''),
+
+    ParameterDetails(
+        'BILL_INSTRUCTIONS',
+        _('Sales'),
+        _('Bill instructions '),
+        # Translators: do not translate $DATE
+        _('When printing bills, include the first 3 lines of these on '
+          'the bill itself. This usually includes instructions on how '
+          'to pay the bill and the validity and the terms. $DATE will be'
+          'replaced with the due date of the bill'),
+        str, multiline=True, initial=""),
+
 ]
 
 
@@ -814,16 +834,13 @@ class ParameterAccess(ClassInittableObject):
         self._create_default_values()
 
     def create_delivery_service(self):
-        from stoqlib.domain.sellable import (BaseSellableInfo,
-                                             Sellable,
+        from stoqlib.domain.sellable import (Sellable,
                                              SellableTaxConstant)
         from stoqlib.domain.service import Service
         key = "DELIVERY_SERVICE"
         tax_constant = SellableTaxConstant.get_by_type(TaxType.SERVICE, self.conn)
-        sellable_info = BaseSellableInfo(connection=self.conn,
-                                         description=_('Delivery'))
         sellable = Sellable(tax_constant=tax_constant,
-                            base_sellable_info=sellable_info,
+                            description=_('Delivery'),
                             connection=self.conn)
         service = Service(sellable=sellable, connection=self.conn)
         self._set_schema(key, service.id)
